@@ -32,14 +32,33 @@
 #include <xf86Xinput.h>
 #include <xisb.h>
 
+#include "config.h"
+
+struct _SynapticsPrivateRec;
+typedef struct _SynapticsPrivateRec SynapticsPrivate;
+
+enum SynapticsSlotState
+{
+    SLOTSTATE_EMPTY = 0,
+    SLOTSTATE_OPEN,
+    SLOTSTATE_CLOSE,
+    SLOTSTATE_OPEN_EMPTY,
+    SLOTSTATE_UPDATE,
+};
+
+/* used to mark emulated hw button state */
+#define BTN_EMULATED_FLAG 0x80
+
 /*
  * A structure to describe the state of the touchpad hardware (buttons and pad)
  */
 struct SynapticsHwState {
-    int millis;			/* Timestamp in milliseconds */
+    CARD32 millis;		/* Timestamp in milliseconds */
     int x;			/* X position of finger */
     int y;			/* Y position of finger */
     int z;			/* Finger pressure */
+    int cumulative_dx;		/* Cumulative delta X for clickpad dragging */
+    int cumulative_dy;		/* Cumulative delta Y for clickpad dragging */
     int numFingers;
     int fingerWidth;
 
@@ -50,6 +69,12 @@ struct SynapticsHwState {
 
     Bool multi[8];
     Bool middle;		/* Some ALPS touchpads have a middle button */
+
+#ifdef HAVE_MULTITOUCH
+    int num_mt_mask;
+    ValuatorMask **mt_mask;
+    enum SynapticsSlotState *slot_state;
+#endif
 };
 
 struct CommData {
@@ -61,7 +86,7 @@ struct CommData {
     int protoBufTail;
 
     /* Used for keeping track of partial HwState updates. */
-    struct SynapticsHwState hwState;
+    struct SynapticsHwState *hwState;
     Bool oneFinger;
     Bool twoFingers;
     Bool threeFingers;
@@ -70,8 +95,8 @@ struct CommData {
 struct _SynapticsParameters;
 
 struct SynapticsProtocolOperations {
-    void (*DeviceOnHook)(InputInfoPtr pInfo, struct _SynapticsParameters *para);
-    void (*DeviceOffHook)(InputInfoPtr pInfo);
+    Bool (*DeviceOnHook)(InputInfoPtr pInfo, struct _SynapticsParameters *para);
+    Bool (*DeviceOffHook)(InputInfoPtr pInfo);
     Bool (*QueryHardware)(InputInfoPtr pInfo);
     Bool (*ReadHwState)(InputInfoPtr pInfo,
 			struct CommData *comm, struct SynapticsHwState *hwRet);
@@ -90,4 +115,13 @@ extern struct SynapticsProtocolOperations event_proto_operations;
 extern struct SynapticsProtocolOperations psm_proto_operations;
 #endif /* BUILD_PSMCOMM */
 
+extern struct SynapticsHwState *SynapticsHwStateAlloc(SynapticsPrivate *priv);
+extern void SynapticsHwStateFree(struct SynapticsHwState **hw);
+extern void SynapticsCopyHwState(struct SynapticsHwState *dst,
+                                 const struct SynapticsHwState *src);
+extern void SynapticsResetHwState(struct SynapticsHwState *hw);
+extern void SynapticsResetTouchHwState(struct SynapticsHwState *hw, Bool force_empty);
+
+extern Bool SynapticsIsSoftButtonAreasValid(int *values);
+
 #endif /* _SYNPROTO_H_ */
